##################
User documentation
##################

.. toctree::
   :maxdepth: 3

  How to get started <Users-Guide>
  Creating a timeline <Creating-a-timeline>
  Troubleshooting <Troubleshooting>
  Using collection Filters <Collection-Filters>
  Event filters <Event-filters>
  Analysis plugins <Analysis-plugins>
  Tips and Tricks <Tips-and-Tricks>
  Log2Timeline Perl (Legacy) <Log2Timeline-Perl-(Legacy)>